'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _utils = require('../utils');

var _normalizeWheel = require('./normalizeWheel');

var _normalizeWheel2 = _interopRequireDefault(_normalizeWheel);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var WheelHandler =
/**
 * onWheel is the callback that will be called with right frame rate if
 * any wheel events happened
 * onWheel should is to be called with two arguments: deltaX and deltaY in
 * this order
 */
function WheelHandler(onWheel, handleScrollX, handleScrollY, stopPropagation) {
  (0, _classCallCheck3.default)(this, WheelHandler);

  _initialiseProps.call(this);

  this.deltaX = 0;
  this.deltaY = 0;
  this.animationFrameID = null;

  this.handleScrollX = (0, _utils.getJudgeFunction)(handleScrollX);
  this.handleScrollY = (0, _utils.getJudgeFunction)(handleScrollY);
  this.stopPropagation = (0, _utils.getJudgeFunction)(stopPropagation);
  this.callback = onWheel;
};

var _initialiseProps = function _initialiseProps() {
  var _this = this;

  this.onWheel = function (e) {
    var normalizedEvent = (0, _normalizeWheel2.default)(e);
    var pixelX = normalizedEvent.pixelX,
        pixelY = normalizedEvent.pixelY;

    var deltaX = _this.deltaX + pixelX;
    var deltaY = _this.deltaY + pixelY;
    var handleScrollX = _this.handleScrollX(deltaX, deltaY);
    var handleScrollY = _this.handleScrollY(deltaY, deltaX);
    if (!handleScrollX && !handleScrollY) {
      return;
    }

    _this.deltaX += handleScrollX ? pixelX : 0;
    _this.deltaY += handleScrollY ? pixelY : 0;

    e.preventDefault();

    var changed = void 0;
    if (_this.deltaX !== 0 || _this.deltaY !== 0) {
      if (_this.stopPropagation()) {
        e.stopPropagation();
      }
      changed = true;
    }

    if (changed === true && _this.animationFrameID === null) {
      _this.animationFrameID = (0, _utils.requestAnimationFrame)(_this.didWheel);
    }
  };

  this.didWheel = function () {
    _this.animationFrameID = null;
    if (_this.callback) {
      _this.callback(_this.deltaX, _this.deltaY);
    }
    _this.deltaX = 0;
    _this.deltaY = 0;
  };
};

exports.default = WheelHandler;
module.exports = exports['default'];